`.datasets` is the code that generate auto-labeled - this is the correct code but I haven't migrated yet.
`.datasets.make_autolabel` is my migrating code for autolabel actor that I'm replacing.
`.make_dataset` is the migrated code that seems working.
